@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::ShareDir::Tarball::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: Bundle your shared dir into a tarball
-$Dist::Zilla::Plugin::ShareDir::Tarball::VERSION = '0.5.0';
+$Dist::Zilla::Plugin::ShareDir::Tarball::VERSION = '0.6.0';
 
 use strict;
 use warnings;
@@ -78,7 +78,7 @@ sub prune_files {
 
     for ( $self->find_files ) {
         ( my $archive_name = $_->name ) =~ s#$src/##;
-        $self->archive->add_data( $archive_name => $_->content );
+        $self->archive->add_data( $archive_name => $_->encoded_content );
         $self->zilla->prune_file($_);
     }
 
@@ -111,7 +111,7 @@ Dist::Zilla::Plugin::ShareDir::Tarball - Bundle your shared dir into a tarball
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
